@@ -6,12 +6,13 @@ use utf8;
 BEGIN
 {
 use strict;
-use vars qw($VERSION @EXPORT_OK %GeezEquivalence);
+use vars qw($VERSION @EXPORT_OK %GeezEquivalence %GeezClassEquivalence);
+# require Regexp::Ethiopic;
 
 
-	$VERSION = "0.06";
+	$VERSION = "0.05";
 	
-	@EXPORT_OK = qw(%GeezEquivalence);
+	@EXPORT_OK = qw(%GeezEquivalence %GeezClassEquivalence);
 
 
 #
@@ -93,6 +94,7 @@ $_ = ($#_) ? $_[1] : $_[0];
 
 
 	s/\[=(\p{Ethiopic})=\]/($GeezEquivalence{$1}) ? "[$GeezEquivalence{$1}]" : $1/eog;
+	s/\[=#(\p{Ethiopic})#=\]/($GeezClassEquivalence{$1}) ? "[$GeezClassEquivalence{$1}]" : $1/eog;
 
 	Regexp::Ethiopic::getRe ( $_ );
 }
@@ -108,7 +110,6 @@ $_ = ($#_) ? $_[1] : $_[0];
 
 __END__
 
-=encoding utf8
 
 =head1 NAME
 
@@ -156,7 +157,7 @@ under Geez orthography rules.
 
 The Regexp::Ethiopic::Geez uses Regexp::Ethiopic so generally you
 would not need to import both.  Regexp::Ethiopic::Geez conditionally
-exports the hash %GeezEquivalence 
+exports the hashes %GeezEquivalence and %GeezClassEquivalence
 should you wish to use them.  Regexp::Ethiopic::Geez can also
 export %EthiopiClass of Regexp::Ethiopic:
 
